==> om-7.x-1.1.tar.gz: om/subtheme/page.tpl.php <==
<?php
// $Id: page.tpl.php,v 1.1.4.1 2011/02/12 01:57:09 danielhonrade Exp $

/**
 * @file
 * Default theme implementation to display a single Drupal page.
 *
 * Available variables:
 *
 * General utility variables:
 * - $base_path: The base URL path of the Drupal installation. At the very
 *   least, this will always default to /.
 * - $directory: The directory the template is located in, e.g. modules/system
 *   or themes/bartik.
 * - $is_front: TRUE if the current page is the front page.
 * - $logged_in: TRUE if the user is registered and signed in.
 * - $is_admin: TRUE if the user has permission to access administration pages.
 *
 * Site identity:
 * - $front_page: The URL of the front page. Use this instead of $base_path,
 *   when linking to the front page. This includes the language domain or
 *   prefix.
 * - $logo: The path to the logo image, as defined in theme configuration.
 * - $site_name: The name of the site, empty when display has been disabled
 *   in theme settings.
 * - $site_slogan: The slogan of the site, empty when display has been disabled
 *   in theme settings.
 *
 * Navigation:
 * - $main_menu (array): An array containing the Main menu links for the
 *   site, if they have been configured.
 * - $secondary_menu (array): An array containing the Secondary menu links for
 *   the site, if they have been configured.
 * - $breadcrumb: The breadcrumb trail for the current page.
 *
 * Page content (in order of occurrence in the default page.tpl.php):
 * - $title_prefix (array): An array containing additional output populated by
 *   modules, intended to be displayed in front of the main title tag that
 *   appears in the template.
 * - $title: The page title, for use in the actual HTML content.
 * - $title_suffix (array): An array containing additional output populated by
 *   modules, intended to be displayed after the main title tag that appears in
 *   the template.
 * - $messages: HTML for status and error messages. Should be displayed
 *   prominently.
 * - $tabs (array): Tabs linking to any sub-pages beneath the current page
 *   (e.g., the view and edit tabs when displaying a node).
 * - $action_links (array): Actions local to the page, such as 'Add menu' on the
 *   menu administration interface.
 * - $feed_icons: A string of all feed icons for the current page.
 * - $node: The node object, if there is an automatically-loaded node
 *   associated with the page, and the node ID is the second argument
 *   in the page's path (e.g. node/12345 and node/12345/revisions, but not
 *   comment/reply/12345).
 *
 * Regions:
 * - $page['help']: Dynamic help text, mostly for admin pages.
 * - $page['highlighted']: Items for the highlighted content region.
 * - $page['content']: The main content of the current page.
 * - $page['sidebar_first']: Items for the first sidebar.
 * - $page['sidebar_second']: Items for the second sidebar.
 * - $page['header']: Items for the header region.
 * - $page['footer']: Items for the footer region.
 *
 * @see template_preprocess()
 * @see template_preprocess_page()
 * @see template_process()
 *
 * Creating a Region 
 * - param: css region-id, variable name from .info, 1 or 0 for creating inner div
 * 
 * <?php print om_region('region-id', $region_name, 1); ?> 
 */
?>
<div class="wrapper-outer">
  <div id="header" class="wrapper"><div id="header-inner" class="wrapper-inner">
    <?php print om_identity($logo, $site_name, $site_slogan, $front_page); ?>
    <?php print om_region_wrapper('header-block', render($page['header']), 1); ?>
    <div class="clearfix"></div>
  </div></div><!-- /#header-inner, /#header -->
  <div id="navigation" class="wrapper"><div id="navigation-inner" class="wrapper-inner">
    <?php print om_region_wrapper('main-menu', render($page['main_menu']), 0); ?>
  </div></div> <!-- /#navigation-inner, /#navigation -->
  <?php print om_region_wrapper('highlighted', render($page['highlighted']), 1); ?>
  <div id="container" class="wrapper"> <div id="container-inner" class="wrapper-inner">
    <?php print om_region_wrapper('sidebar-first', render($page['sidebar_first']), 1); ?>
    <?php print om_region_wrapper('sidebar-second', render($page['sidebar_second']), 1); ?>
    <div id="main">
      <?php print om_breadcrumb($breadcrumb); ?>
      <div id="main-inner">
        <?php print om_content_elements(render($tabs), render($title_prefix), $title, render($title_suffix), $messages, render($page['help']), render($action_links)); ?>
        <?php print om_region_wrapper('content', render($page['content']), 1); ?>
        <?php print $feed_icons; ?>
      </div> <!-- /main-inner -->
    </div> <!-- /#main -->
    <div class="clearfix"></div>
  </div></div> <!-- /#container-inner, /#container -->
  <div id="footer" class="wrapper"><div id="footer-inner" class="wrapper-inner">
    <?php print om_region_wrapper('footer', render($page['footer']), 1); ?>
  </div></div> <!-- /#footer-inner, /#footer -->
</div> <!-- /#wrapper-outer -->

==> om-7.x-1.2.tar.gz: om/subtheme/page.tpl.php <==
<?php
// $Id: page.tpl.php,v 1.1.4.2 2011/02/12 03:35:37 danielhonrade Exp $

/**
 * @file
 * Default theme implementation to display a single Drupal page.
 *
 * Available variables:
 *
 * General utility variables:
 * - $base_path: The base URL path of the Drupal installation. At the very
 *   least, this will always default to /.
 * - $directory: The directory the template is located in, e.g. modules/system
 *   or themes/bartik.
 * - $is_front: TRUE if the current page is the front page.
 * - $logged_in: TRUE if the user is registered and signed in.
 * - $is_admin: TRUE if the user has permission to access administration pages.
 *
 * Site identity:
 * - $front_page: The URL of the front page. Use this instead of $base_path,
 *   when linking to the front page. This includes the language domain or
 *   prefix.
 * - $logo: The path to the logo image, as defined in theme configuration.
 * - $site_name: The name of the site, empty when display has been disabled
 *   in theme settings.
 * - $site_slogan: The slogan of the site, empty when display has been disabled
 *   in theme settings.
 *
 * Navigation:
 * - $main_menu (array): An array containing the Main menu links for the
 *   site, if they have been configured.
 * - $secondary_menu (array): An array containing the Secondary menu links for
 *   the site, if they have been configured.
 * - $breadcrumb: The breadcrumb trail for the current page.
 *
 * Page content (in order of occurrence in the default page.tpl.php):
 * - $title_prefix (array): An array containing additional output populated by
 *   modules, intended to be displayed in front of the main title tag that
 *   appears in the template.
 * - $title: The page title, for use in the actual HTML content.
 * - $title_suffix (array): An array containing additional output populated by
 *   modules, intended to be displayed after the main title tag that appears in
 *   the template.
 * - $messages: HTML for status and error messages. Should be displayed
 *   prominently.
 * - $tabs (array): Tabs linking to any sub-pages beneath the current page
 *   (e.g., the view and edit tabs when displaying a node).
 * - $action_links (array): Actions local to the page, such as 'Add menu' on the
 *   menu administration interface.
 * - $feed_icons: A string of all feed icons for the current page.
 * - $node: The node object, if there is an automatically-loaded node
 *   associated with the page, and the node ID is the second argument
 *   in the page's path (e.g. node/12345 and node/12345/revisions, but not
 *   comment/reply/12345).
 *
 * Regions:
 * - $page['help']: Dynamic help text, mostly for admin pages.
 * - $page['highlighted']: Items for the highlighted content region.
 * - $page['content']: The main content of the current page.
 * - $page['sidebar_first']: Items for the first sidebar.
 * - $page['sidebar_second']: Items for the second sidebar.
 * - $page['header']: Items for the header region.
 * - $page['footer']: Items for the footer region.
 *
 * @see template_preprocess()
 * @see template_preprocess_page()
 * @see template_process()
 *
 * Creating a Region 
 * - param: css region-id, variable name from .info, 1 or 0 for creating inner div
 * 
 * <?php print om_region('region-id', $region_name, 1); ?> 
 */
?>
<div class="wrapper-outer">
  <div id="header" class="wrapper"><div id="header-inner" class="wrapper-inner">
    <?php print om_identity($logo, $site_name, $site_slogan, $front_page); ?>
    <?php print om_region_wrapper('header-block', render($page['header']), 1); ?>
    <div class="clearfix"></div>
  </div></div><!-- /#header-inner, /#header -->
  <div id="navigation" class="wrapper"><div id="navigation-inner" class="wrapper-inner">
    <?php print om_region_wrapper('main-menu', render($page['main_menu']), 0); ?>
  </div></div> <!-- /#navigation-inner, /#navigation -->
  <?php print om_region_wrapper('highlighted', render($page['highlighted']), 1); ?>
  <div id="container" class="wrapper"> <div id="container-inner" class="wrapper-inner">
    <?php print om_region_wrapper('sidebar-first', render($page['sidebar_first']), 1); ?>
    <?php print om_region_wrapper('sidebar-second', render($page['sidebar_second']), 1); ?>
    <div id="main">
      <?php print om_breadcrumb_wrapper($breadcrumb); ?>
      <div id="main-inner">
        <?php print om_content_elements(render($tabs), render($title_prefix), $title, render($title_suffix), $messages, render($page['help']), render($action_links)); ?>
        <?php print om_region_wrapper('content', render($page['content']), 1); ?>
        <?php print $feed_icons; ?>
      </div> <!-- /main-inner -->
    </div> <!-- /#main -->
    <div class="clearfix"></div>
  </div></div> <!-- /#container-inner, /#container -->
  <div id="footer" class="wrapper"><div id="footer-inner" class="wrapper-inner">
    <?php print om_region_wrapper('footer', render($page['footer']), 1); ?>
  </div></div> <!-- /#footer-inner, /#footer -->
</div> <!-- /#wrapper-outer -->
